
/*
 Copyright (C) 2003 Martin A. Olevitch
 Written by Martin A. Olevitch (marty@cosray.wustl.edu)

 This file is part of Stor.

 Stor is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 Stor is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with Stor, see the file COPYING; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

// stor.h

#ifndef _STOR_H
#define _STOR_H

#include <string>
#include <fstream>

class stor {
    public:
    	stor(std::string _datadir, long _maxfilesize,
	    bool _do_default_comment = true) /* throw (std::string)*/;
	void next_run() /* throw (std::string)*/;
	long next_file() /* throw (std::string)*/;
	void flush() /* throw (std::string)*/;
	int save_data(const char *dp, int n) /* throw (std::string)*/;
	void close();
	void comment(const std::string& s);
	void comment(const char *s);
	~stor();

	long cur_run() const;
	long cur_file() const;
	long bytes_cur_file() const;
	long total_bytes() const;
	std::string cur_file_str() const;
	std::string cur_run_str() const;
	std::string cur_file_path() const;
	static std::string version();

    private:
	std::string active_file;	// name of "active" file
	std::string cur_run_name_file;
	std::string datadir;		// root directory of all the runs
	bool do_default_comment;
	long file;		// current file number
	std::ofstream filestream;	// current output file stream
	long filesize;		// size (bytes) of current file
	long maxfilesize;	// max size (bytes) of each data file
    	long run;		// current run number
	std::string rundir;		// root dir of current run
	bool switch_data_files;	// 0 to put all data in one file
	unsigned long totbytes;	// total bytes writ by this stor

	// Disallow copying by having private copy constructor and
	// assignment operator.
	stor(const stor&);
	stor& operator=(const stor&);
};

#endif // _STOR_H
